@@ -22,6 +22,7 @@ import time
 import traceback
 import zmq
 
+from ducktape.cluster.node_container import InsufficientResourcesError
 from ducktape.tests.serde import SerDe
 from ducktape.tests.test import TestContext
 from ducktape.command_line.defaults import ConsoleDefaults
@@ -120,6 +121,7 @@ class TestRunner(object):
         self._client_procs = {}  # track client processes running tests
         self.active_tests = {}
         self.finished_tests = {}
+        self.test_schedule_log = []
 
     def _propagate_sigterm(self, signum, frame):
         """Handler SIGTERM and SIGINT by propagating SIGTERM to all client processes.
@@ -161,34 +163,43 @@ class TestRunner(object):
     def _expect_client_requests(self):
         return len(self.active_tests) > 0
 
+    def _report_unschedulable(self, unschedulable, err_msg=None):
+        if not unschedulable:
+            return
+
+        self._log(logging.ERROR,
+                  f"There are {len(unschedulable)} tests which cannot be run due to insufficient cluster resources")
+        for tc in unschedulable:
+            if err_msg:
+                msg = err_msg
+            else:
+                msg = f"Test {tc.test_id} requires more resources than are available in the whole cluster. " \
+                      f"{self.cluster.all().nodes.attempt_remove_spec(tc.expected_cluster_spec)}"
+
+            self._log(logging.ERROR, msg)
+
+            result = TestResult(
+                tc,
+                self.test_counter,
+                self.session_context,
+                test_status=FAIL,
+                summary=msg,
+                start_time=time.time(),
+                stop_time=time.time())
+            self.results.append(result)
+            result.report()
+
+            self.test_counter += 1
+
+    def _check_unschedulable(self):
+        self._report_unschedulable(self.scheduler.filter_unschedulable_tests())
+
     def run_all_tests(self):
         self.receiver.start()
         self.results.start_time = time.time()
 
         # Report tests which cannot be run
-        if len(self.scheduler.unschedulable) > 0:
-            self._log(logging.ERROR,
-                      "There are %d tests which cannot be run due to insufficient cluster resources" %
-                      len(self.scheduler.unschedulable))
-
-            for tc in self.scheduler.unschedulable:
-                msg = "Test %s requires more resources than are available in the whole cluster. " % tc.test_id
-                msg += self.cluster.all().nodes.attempt_remove_spec(tc.expected_cluster_spec)
-
-                self._log(logging.ERROR, msg)
-
-                result = TestResult(
-                    tc,
-                    self.test_counter,
-                    self.session_context,
-                    test_status=FAIL,
-                    summary=msg,
-                    start_time=time.time(),
-                    stop_time=time.time())
-                self.results.append(result)
-                result.report()
-
-                self.test_counter += 1
+        self._check_unschedulable()
 
         # Run the tests!
         self._log(logging.INFO, "starting test run with session id %s..." % self.session_context.session_id)
@@ -196,9 +207,26 @@ class TestRunner(object):
         while self._ready_to_trigger_more_tests or self._expect_client_requests:
             try:
                 while self._ready_to_trigger_more_tests:
-                    next_test_context = self.scheduler.next()
-                    self._preallocate_subcluster(next_test_context)
-                    self._run_single_test(next_test_context)
+                    next_test_context = self.scheduler.peek()
+                    try:
+                        self._preallocate_subcluster(next_test_context)
+                    except InsufficientResourcesError:
+                        # We were not able to allocate the subcluster for this test,
+                        # this means not enough nodes passed health check.
+                        # Don't mark this test as failed just yet, some other test might finish running and
+                        # free up healthy nodes.
+                        # However, if some nodes failed, cluster size changed too, so we need to check if
+                        # there are any tests that can no longer be scheduled.
+                        self._log(
+                            logging.INFO,
+                            f"Couldn't schedule test context {next_test_context} but we'll keep trying",
+                            exc_info=True
+                        )
+                        self._check_unschedulable()
+                    else:
+                        # only remove the test from the scheduler once we've successfully allocated a subcluster for it
+                        self.scheduler.remove(next_test_context)
+                        self._run_single_test(next_test_context)
 
                 if self._expect_client_requests:
                     try:
@@ -235,6 +263,7 @@ class TestRunner(object):
         # Test is considered "active" as soon as we start it up in a subprocess
         test_key = TestKey(test_context.test_id, current_test_counter)
         self.active_tests[test_key] = True
+        self.test_schedule_log.append(test_key)
 
         proc = multiprocessing.Process(
             target=run_client,
