@@ -21,6 +21,8 @@ import random
 import pytest
 from ducktape.cluster.remoteaccount import RemoteAccountError
 
+from tests.runner.fake_remote_account import create_fake_remote_account
+
 TWO_HOSTS = """Host worker1
   HostName 127.0.0.1
   User vagrant
@@ -46,6 +48,10 @@ Host worker2
 """
 
 
+def make_vagrant_cluster(*args, **kwargs):
+    return VagrantCluster(make_remote_account_func=create_fake_remote_account, *args, **kwargs)
+
+
 class CheckVagrantCluster(object):
 
     def setup_method(self, _):
@@ -76,7 +82,7 @@ class CheckVagrantCluster(object):
         """
         self._set_monkeypatch_attr(monkeypatch)
 
-        cluster = VagrantCluster()
+        cluster = make_vagrant_cluster()
         assert len(cluster) == 2
         assert cluster.num_available_nodes() == 2
         node1, node2 = cluster.alloc(Service.setup_cluster_spec(num_nodes=2))
@@ -97,7 +103,7 @@ class CheckVagrantCluster(object):
         self._set_monkeypatch_attr(monkeypatch)
         assert not os.path.exists(self.cluster_file)
 
-        cluster = VagrantCluster(cluster_file=self.cluster_file)
+        cluster = make_vagrant_cluster(cluster_file=self.cluster_file)
         cluster_json_expected = {}
         nodes = [
             {
@@ -108,7 +114,8 @@ class CheckVagrantCluster(object):
                     "user": node_account.ssh_config.user,
                     "identityfile": node_account.ssh_config.identityfile,
                     "password": node_account.ssh_config.password,
-                    "port": node_account.ssh_config.port
+                    "port": node_account.ssh_config.port,
+                    "connecttimeout": None
                 }
             }
             for node_account in cluster._available_accounts
@@ -136,7 +143,8 @@ class CheckVagrantCluster(object):
                 "user": "vagrant",
                 "port": 2222,
                 "password": "password",
-                "identityfile": "/path/to/identfile3"
+                "identityfile": "/path/to/identfile3",
+                "connecttimeout": None
             }
         }
         nodes_expected.append(node1_expected)
@@ -149,7 +157,8 @@ class CheckVagrantCluster(object):
                 "user": "vagrant",
                 "port": 2223,
                 "password": None,
-                "identityfile": "/path/to/indentfile2"
+                "identityfile": "/path/to/indentfile2",
+                "connecttimeout": 10
             }
         }
         nodes_expected.append(node2_expected)
@@ -160,7 +169,7 @@ class CheckVagrantCluster(object):
                   indent=2, separators=(',', ': '), sort_keys=True)
 
         # Load the cluster from the json file we just created
-        cluster = VagrantCluster(cluster_file=self.cluster_file)
+        cluster = make_vagrant_cluster(cluster_file=self.cluster_file)
 
         assert len(cluster) == 2
         assert cluster.num_available_nodes() == 2
